/* InstanceV2.c generated by valac 0.56.19, the Vala compiler
 * generated from InstanceV2.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_INSTANCE_V2 (tuba_api_instance_v2_get_type ())
#define TUBA_API_INSTANCE_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_INSTANCE_V2, TubaAPIInstanceV2))
#define TUBA_API_INSTANCE_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_INSTANCE_V2, TubaAPIInstanceV2Class))
#define TUBA_API_IS_INSTANCE_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_INSTANCE_V2))
#define TUBA_API_IS_INSTANCE_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_INSTANCE_V2))
#define TUBA_API_INSTANCE_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_INSTANCE_V2, TubaAPIInstanceV2Class))

typedef struct _TubaAPIInstanceV2 TubaAPIInstanceV2;
typedef struct _TubaAPIInstanceV2Class TubaAPIInstanceV2Class;
typedef struct _TubaAPIInstanceV2Private TubaAPIInstanceV2Private;

#define TUBA_API_INSTANCE_V2_TYPE_CONFIGURATION (tuba_api_instance_v2_configuration_get_type ())
#define TUBA_API_INSTANCE_V2_CONFIGURATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_INSTANCE_V2_TYPE_CONFIGURATION, TubaAPIInstanceV2Configuration))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_INSTANCE_V2_TYPE_CONFIGURATION, TubaAPIInstanceV2ConfigurationClass))
#define TUBA_API_INSTANCE_V2_IS_CONFIGURATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_INSTANCE_V2_TYPE_CONFIGURATION))
#define TUBA_API_INSTANCE_V2_IS_CONFIGURATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_INSTANCE_V2_TYPE_CONFIGURATION))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_INSTANCE_V2_TYPE_CONFIGURATION, TubaAPIInstanceV2ConfigurationClass))

typedef struct _TubaAPIInstanceV2Configuration TubaAPIInstanceV2Configuration;
typedef struct _TubaAPIInstanceV2ConfigurationClass TubaAPIInstanceV2ConfigurationClass;

#define TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS (tuba_api_instance_v2_api_versions_get_type ())
#define TUBA_API_INSTANCE_V2_API_VERSIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersions))
#define TUBA_API_INSTANCE_V2_API_VERSIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersionsClass))
#define TUBA_API_INSTANCE_V2_IS_API_VERSIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS))
#define TUBA_API_INSTANCE_V2_IS_API_VERSIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS))
#define TUBA_API_INSTANCE_V2_API_VERSIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersionsClass))

typedef struct _TubaAPIInstanceV2APIVersions TubaAPIInstanceV2APIVersions;
typedef struct _TubaAPIInstanceV2APIVersionsClass TubaAPIInstanceV2APIVersionsClass;
enum  {
	TUBA_API_INSTANCE_V2_0_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_PROPERTY,
	TUBA_API_INSTANCE_V2_API_VERSIONS_PROPERTY,
	TUBA_API_INSTANCE_V2_NUM_PROPERTIES
};
static GParamSpec* tuba_api_instance_v2_properties[TUBA_API_INSTANCE_V2_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _TubaAPIInstanceV2ConfigurationPrivate TubaAPIInstanceV2ConfigurationPrivate;

#define TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_TRANSLATION (tuba_api_instance_v2_configuration_translation_get_type ())
#define TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_TRANSLATION, TubaAPIInstanceV2ConfigurationTranslation))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_TRANSLATION, TubaAPIInstanceV2ConfigurationTranslationClass))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_IS_TRANSLATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_TRANSLATION))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_IS_TRANSLATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_TRANSLATION))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_TRANSLATION, TubaAPIInstanceV2ConfigurationTranslationClass))

typedef struct _TubaAPIInstanceV2ConfigurationTranslation TubaAPIInstanceV2ConfigurationTranslation;
typedef struct _TubaAPIInstanceV2ConfigurationTranslationClass TubaAPIInstanceV2ConfigurationTranslationClass;

#define TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS (tuba_api_instance_v2_configuration_media_attachments_get_type ())
#define TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIInstanceV2ConfigurationMediaAttachments))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIInstanceV2ConfigurationMediaAttachmentsClass))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_IS_MEDIA_ATTACHMENTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_IS_MEDIA_ATTACHMENTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIInstanceV2ConfigurationMediaAttachmentsClass))

typedef struct _TubaAPIInstanceV2ConfigurationMediaAttachments TubaAPIInstanceV2ConfigurationMediaAttachments;
typedef struct _TubaAPIInstanceV2ConfigurationMediaAttachmentsClass TubaAPIInstanceV2ConfigurationMediaAttachmentsClass;

#define TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_VAPID (tuba_api_instance_v2_configuration_vapid_get_type ())
#define TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_VAPID, TubaAPIInstanceV2ConfigurationVapid))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_VAPID, TubaAPIInstanceV2ConfigurationVapidClass))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_IS_VAPID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_VAPID))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_IS_VAPID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_VAPID))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_VAPID, TubaAPIInstanceV2ConfigurationVapidClass))

typedef struct _TubaAPIInstanceV2ConfigurationVapid TubaAPIInstanceV2ConfigurationVapid;
typedef struct _TubaAPIInstanceV2ConfigurationVapidClass TubaAPIInstanceV2ConfigurationVapidClass;

#define TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS (tuba_api_instance_v2_configuration_accounts_char_limits_get_type ())
#define TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS, TubaAPIInstanceV2ConfigurationAccountsCharLimits))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS, TubaAPIInstanceV2ConfigurationAccountsCharLimitsClass))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_IS_ACCOUNTS_CHAR_LIMITS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_IS_ACCOUNTS_CHAR_LIMITS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS, TubaAPIInstanceV2ConfigurationAccountsCharLimitsClass))

typedef struct _TubaAPIInstanceV2ConfigurationAccountsCharLimits TubaAPIInstanceV2ConfigurationAccountsCharLimits;
typedef struct _TubaAPIInstanceV2ConfigurationAccountsCharLimitsClass TubaAPIInstanceV2ConfigurationAccountsCharLimitsClass;
enum  {
	TUBA_API_INSTANCE_V2_CONFIGURATION_0_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_NUM_PROPERTIES
};
static GParamSpec* tuba_api_instance_v2_configuration_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_NUM_PROPERTIES];
typedef struct _TubaAPIInstanceV2ConfigurationTranslationPrivate TubaAPIInstanceV2ConfigurationTranslationPrivate;
enum  {
	TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_0_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_ENABLED_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_NUM_PROPERTIES
};
static GParamSpec* tuba_api_instance_v2_configuration_translation_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_NUM_PROPERTIES];
typedef struct _TubaAPIInstanceV2ConfigurationMediaAttachmentsPrivate TubaAPIInstanceV2ConfigurationMediaAttachmentsPrivate;
enum  {
	TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_0_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_DESCRIPTION_LIMIT_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_NUM_PROPERTIES
};
static GParamSpec* tuba_api_instance_v2_configuration_media_attachments_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_NUM_PROPERTIES];
typedef struct _TubaAPIInstanceV2ConfigurationVapidPrivate TubaAPIInstanceV2ConfigurationVapidPrivate;
enum  {
	TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_0_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PUBLIC_KEY_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_NUM_PROPERTIES
};
static GParamSpec* tuba_api_instance_v2_configuration_vapid_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _TubaAPIInstanceV2ConfigurationAccountsCharLimitsPrivate TubaAPIInstanceV2ConfigurationAccountsCharLimitsPrivate;
enum  {
	TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_0_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_DISPLAY_NAME_LENGTH_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_NOTE_LENGTH_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_AVATAR_DESCRIPTION_LENGTH_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_HEADER_DESCRIPTION_LENGTH_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_PROFILE_FIELDS_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_NAME_LIMIT_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_VALUE_LIMIT_PROPERTY,
	TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_NUM_PROPERTIES
};
static GParamSpec* tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_NUM_PROPERTIES];
typedef struct _TubaAPIInstanceV2APIVersionsPrivate TubaAPIInstanceV2APIVersionsPrivate;
enum  {
	TUBA_API_INSTANCE_V2_API_VERSIONS_0_PROPERTY,
	TUBA_API_INSTANCE_V2_API_VERSIONS_MASTODON_PROPERTY,
	TUBA_API_INSTANCE_V2_API_VERSIONS_CHUCKYA_PROPERTY,
	TUBA_API_INSTANCE_V2_API_VERSIONS_NUM_PROPERTIES
};
static GParamSpec* tuba_api_instance_v2_api_versions_properties[TUBA_API_INSTANCE_V2_API_VERSIONS_NUM_PROPERTIES];

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIInstanceV2 {
	TubaEntity parent_instance;
	TubaAPIInstanceV2Private * priv;
};

struct _TubaAPIInstanceV2Class {
	TubaEntityClass parent_class;
};

struct _TubaAPIInstanceV2Private {
	TubaAPIInstanceV2Configuration* _configuration;
	TubaAPIInstanceV2APIVersions* _api_versions;
};

struct _TubaAPIInstanceV2Configuration {
	TubaEntity parent_instance;
	TubaAPIInstanceV2ConfigurationPrivate * priv;
};

struct _TubaAPIInstanceV2ConfigurationClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIInstanceV2ConfigurationPrivate {
	TubaAPIInstanceV2ConfigurationTranslation* _translation;
	TubaAPIInstanceV2ConfigurationMediaAttachments* _media_attachments;
	TubaAPIInstanceV2ConfigurationVapid* _vapid;
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* _accounts;
};

struct _TubaAPIInstanceV2ConfigurationTranslation {
	TubaEntity parent_instance;
	TubaAPIInstanceV2ConfigurationTranslationPrivate * priv;
};

struct _TubaAPIInstanceV2ConfigurationTranslationClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIInstanceV2ConfigurationTranslationPrivate {
	gboolean _enabled;
};

struct _TubaAPIInstanceV2ConfigurationMediaAttachments {
	TubaEntity parent_instance;
	TubaAPIInstanceV2ConfigurationMediaAttachmentsPrivate * priv;
};

struct _TubaAPIInstanceV2ConfigurationMediaAttachmentsClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIInstanceV2ConfigurationMediaAttachmentsPrivate {
	gint64 _description_limit;
};

struct _TubaAPIInstanceV2ConfigurationVapid {
	TubaEntity parent_instance;
	TubaAPIInstanceV2ConfigurationVapidPrivate * priv;
};

struct _TubaAPIInstanceV2ConfigurationVapidClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIInstanceV2ConfigurationVapidPrivate {
	gchar* _public_key;
};

struct _TubaAPIInstanceV2ConfigurationAccountsCharLimits {
	TubaEntity parent_instance;
	TubaAPIInstanceV2ConfigurationAccountsCharLimitsPrivate * priv;
};

struct _TubaAPIInstanceV2ConfigurationAccountsCharLimitsClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIInstanceV2ConfigurationAccountsCharLimitsPrivate {
	gint64 _max_display_name_length;
	gint64 _max_note_length;
	gint64 _max_avatar_description_length;
	gint64 _max_header_description_length;
	gint64 _max_profile_fields;
	gint64 _profile_field_name_limit;
	gint64 _profile_field_value_limit;
};

struct _TubaAPIInstanceV2APIVersions {
	TubaEntity parent_instance;
	TubaAPIInstanceV2APIVersionsPrivate * priv;
};

struct _TubaAPIInstanceV2APIVersionsClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIInstanceV2APIVersionsPrivate {
	gint8 _mastodon;
	gint8 _chuckya;
};

static gint TubaAPIInstanceV2_private_offset;
static gpointer tuba_api_instance_v2_parent_class = NULL;
static gint TubaAPIInstanceV2Configuration_private_offset;
static gpointer tuba_api_instance_v2_configuration_parent_class = NULL;
static gint TubaAPIInstanceV2ConfigurationTranslation_private_offset;
static gpointer tuba_api_instance_v2_configuration_translation_parent_class = NULL;
static gint TubaAPIInstanceV2ConfigurationMediaAttachments_private_offset;
static gpointer tuba_api_instance_v2_configuration_media_attachments_parent_class = NULL;
static gint TubaAPIInstanceV2ConfigurationVapid_private_offset;
static gpointer tuba_api_instance_v2_configuration_vapid_parent_class = NULL;
static gint TubaAPIInstanceV2ConfigurationAccountsCharLimits_private_offset;
static gpointer tuba_api_instance_v2_configuration_accounts_char_limits_parent_class = NULL;
static gint TubaAPIInstanceV2APIVersions_private_offset;
static gpointer tuba_api_instance_v2_api_versions_parent_class = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_instance_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceV2, g_object_unref)
VALA_EXTERN GType tuba_api_instance_v2_configuration_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceV2Configuration, g_object_unref)
VALA_EXTERN GType tuba_api_instance_v2_api_versions_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceV2APIVersions, g_object_unref)
VALA_EXTERN TubaAPIInstanceV2* tuba_api_instance_v2_from (JsonNode* node,
                                              GError** error);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
VALA_EXTERN TubaAPIInstanceV2* tuba_api_instance_v2_new (void);
VALA_EXTERN TubaAPIInstanceV2* tuba_api_instance_v2_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN TubaAPIInstanceV2Configuration* tuba_api_instance_v2_get_configuration (TubaAPIInstanceV2* self);
VALA_EXTERN void tuba_api_instance_v2_set_configuration (TubaAPIInstanceV2* self,
                                             TubaAPIInstanceV2Configuration* value);
VALA_EXTERN TubaAPIInstanceV2APIVersions* tuba_api_instance_v2_get_api_versions (TubaAPIInstanceV2* self);
VALA_EXTERN void tuba_api_instance_v2_set_api_versions (TubaAPIInstanceV2* self,
                                            TubaAPIInstanceV2APIVersions* value);
VALA_EXTERN GType tuba_api_instance_v2_configuration_translation_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceV2ConfigurationTranslation, g_object_unref)
VALA_EXTERN GType tuba_api_instance_v2_configuration_media_attachments_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceV2ConfigurationMediaAttachments, g_object_unref)
VALA_EXTERN GType tuba_api_instance_v2_configuration_vapid_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceV2ConfigurationVapid, g_object_unref)
VALA_EXTERN GType tuba_api_instance_v2_configuration_accounts_char_limits_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceV2ConfigurationAccountsCharLimits, g_object_unref)
VALA_EXTERN TubaAPIInstanceV2Configuration* tuba_api_instance_v2_configuration_new (void);
VALA_EXTERN TubaAPIInstanceV2Configuration* tuba_api_instance_v2_configuration_construct (GType object_type);
VALA_EXTERN TubaAPIInstanceV2ConfigurationTranslation* tuba_api_instance_v2_configuration_get_translation (TubaAPIInstanceV2Configuration* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_set_translation (TubaAPIInstanceV2Configuration* self,
                                                         TubaAPIInstanceV2ConfigurationTranslation* value);
VALA_EXTERN TubaAPIInstanceV2ConfigurationMediaAttachments* tuba_api_instance_v2_configuration_get_media_attachments (TubaAPIInstanceV2Configuration* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_set_media_attachments (TubaAPIInstanceV2Configuration* self,
                                                               TubaAPIInstanceV2ConfigurationMediaAttachments* value);
VALA_EXTERN TubaAPIInstanceV2ConfigurationVapid* tuba_api_instance_v2_configuration_get_vapid (TubaAPIInstanceV2Configuration* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_set_vapid (TubaAPIInstanceV2Configuration* self,
                                                   TubaAPIInstanceV2ConfigurationVapid* value);
VALA_EXTERN TubaAPIInstanceV2ConfigurationAccountsCharLimits* tuba_api_instance_v2_configuration_get_accounts (TubaAPIInstanceV2Configuration* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_set_accounts (TubaAPIInstanceV2Configuration* self,
                                                      TubaAPIInstanceV2ConfigurationAccountsCharLimits* value);
VALA_EXTERN TubaAPIInstanceV2ConfigurationTranslation* tuba_api_instance_v2_configuration_translation_new (void);
VALA_EXTERN TubaAPIInstanceV2ConfigurationTranslation* tuba_api_instance_v2_configuration_translation_construct (GType object_type);
VALA_EXTERN gboolean tuba_api_instance_v2_configuration_translation_get_enabled (TubaAPIInstanceV2ConfigurationTranslation* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_translation_set_enabled (TubaAPIInstanceV2ConfigurationTranslation* self,
                                                                 gboolean value);
static void tuba_api_instance_v2_configuration_translation_finalize (GObject * obj);
static GType tuba_api_instance_v2_configuration_translation_get_type_once (void);
static void _vala_tuba_api_instance_v2_configuration_translation_get_property (GObject * object,
                                                                        guint property_id,
                                                                        GValue * value,
                                                                        GParamSpec * pspec);
static void _vala_tuba_api_instance_v2_configuration_translation_set_property (GObject * object,
                                                                        guint property_id,
                                                                        const GValue * value,
                                                                        GParamSpec * pspec);
VALA_EXTERN TubaAPIInstanceV2ConfigurationMediaAttachments* tuba_api_instance_v2_configuration_media_attachments_new (void);
VALA_EXTERN TubaAPIInstanceV2ConfigurationMediaAttachments* tuba_api_instance_v2_configuration_media_attachments_construct (GType object_type);
VALA_EXTERN gint64 tuba_api_instance_v2_configuration_media_attachments_get_description_limit (TubaAPIInstanceV2ConfigurationMediaAttachments* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_media_attachments_set_description_limit (TubaAPIInstanceV2ConfigurationMediaAttachments* self,
                                                                                 gint64 value);
static void tuba_api_instance_v2_configuration_media_attachments_finalize (GObject * obj);
static GType tuba_api_instance_v2_configuration_media_attachments_get_type_once (void);
static void _vala_tuba_api_instance_v2_configuration_media_attachments_get_property (GObject * object,
                                                                              guint property_id,
                                                                              GValue * value,
                                                                              GParamSpec * pspec);
static void _vala_tuba_api_instance_v2_configuration_media_attachments_set_property (GObject * object,
                                                                              guint property_id,
                                                                              const GValue * value,
                                                                              GParamSpec * pspec);
VALA_EXTERN TubaAPIInstanceV2ConfigurationVapid* tuba_api_instance_v2_configuration_vapid_new (void);
VALA_EXTERN TubaAPIInstanceV2ConfigurationVapid* tuba_api_instance_v2_configuration_vapid_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_instance_v2_configuration_vapid_get_public_key (TubaAPIInstanceV2ConfigurationVapid* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_vapid_set_public_key (TubaAPIInstanceV2ConfigurationVapid* self,
                                                              const gchar* value);
static void tuba_api_instance_v2_configuration_vapid_finalize (GObject * obj);
static GType tuba_api_instance_v2_configuration_vapid_get_type_once (void);
static void _vala_tuba_api_instance_v2_configuration_vapid_get_property (GObject * object,
                                                                  guint property_id,
                                                                  GValue * value,
                                                                  GParamSpec * pspec);
static void _vala_tuba_api_instance_v2_configuration_vapid_set_property (GObject * object,
                                                                  guint property_id,
                                                                  const GValue * value,
                                                                  GParamSpec * pspec);
VALA_EXTERN TubaAPIInstanceV2ConfigurationAccountsCharLimits* tuba_api_instance_v2_configuration_accounts_char_limits_new (void);
VALA_EXTERN TubaAPIInstanceV2ConfigurationAccountsCharLimits* tuba_api_instance_v2_configuration_accounts_char_limits_construct (GType object_type);
VALA_EXTERN gint64 tuba_api_instance_v2_configuration_accounts_char_limits_get_max_display_name_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_accounts_char_limits_set_max_display_name_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                          gint64 value);
VALA_EXTERN gint64 tuba_api_instance_v2_configuration_accounts_char_limits_get_max_note_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_accounts_char_limits_set_max_note_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                  gint64 value);
VALA_EXTERN gint64 tuba_api_instance_v2_configuration_accounts_char_limits_get_max_avatar_description_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_accounts_char_limits_set_max_avatar_description_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                                gint64 value);
VALA_EXTERN gint64 tuba_api_instance_v2_configuration_accounts_char_limits_get_max_header_description_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_accounts_char_limits_set_max_header_description_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                                gint64 value);
VALA_EXTERN gint64 tuba_api_instance_v2_configuration_accounts_char_limits_get_max_profile_fields (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_accounts_char_limits_set_max_profile_fields (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                     gint64 value);
VALA_EXTERN gint64 tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_name_limit (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_accounts_char_limits_set_profile_field_name_limit (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                           gint64 value);
VALA_EXTERN gint64 tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_value_limit (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self);
VALA_EXTERN void tuba_api_instance_v2_configuration_accounts_char_limits_set_profile_field_value_limit (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                            gint64 value);
static void tuba_api_instance_v2_configuration_accounts_char_limits_finalize (GObject * obj);
static GType tuba_api_instance_v2_configuration_accounts_char_limits_get_type_once (void);
static void _vala_tuba_api_instance_v2_configuration_accounts_char_limits_get_property (GObject * object,
                                                                                 guint property_id,
                                                                                 GValue * value,
                                                                                 GParamSpec * pspec);
static void _vala_tuba_api_instance_v2_configuration_accounts_char_limits_set_property (GObject * object,
                                                                                 guint property_id,
                                                                                 const GValue * value,
                                                                                 GParamSpec * pspec);
static void tuba_api_instance_v2_configuration_finalize (GObject * obj);
static GType tuba_api_instance_v2_configuration_get_type_once (void);
static void _vala_tuba_api_instance_v2_configuration_get_property (GObject * object,
                                                            guint property_id,
                                                            GValue * value,
                                                            GParamSpec * pspec);
static void _vala_tuba_api_instance_v2_configuration_set_property (GObject * object,
                                                            guint property_id,
                                                            const GValue * value,
                                                            GParamSpec * pspec);
VALA_EXTERN gboolean tuba_api_instance_v2_api_versions_tuba_same (TubaAPIInstanceV2APIVersions* self,
                                                      TubaAPIInstanceV2APIVersions* new_val);
VALA_EXTERN gint8 tuba_api_instance_v2_api_versions_get_mastodon (TubaAPIInstanceV2APIVersions* self);
VALA_EXTERN gint8 tuba_api_instance_v2_api_versions_get_chuckya (TubaAPIInstanceV2APIVersions* self);
VALA_EXTERN TubaAPIInstanceV2APIVersions* tuba_api_instance_v2_api_versions_new (void);
VALA_EXTERN TubaAPIInstanceV2APIVersions* tuba_api_instance_v2_api_versions_construct (GType object_type);
VALA_EXTERN void tuba_api_instance_v2_api_versions_set_mastodon (TubaAPIInstanceV2APIVersions* self,
                                                     gint8 value);
VALA_EXTERN void tuba_api_instance_v2_api_versions_set_chuckya (TubaAPIInstanceV2APIVersions* self,
                                                    gint8 value);
static void tuba_api_instance_v2_api_versions_finalize (GObject * obj);
static GType tuba_api_instance_v2_api_versions_get_type_once (void);
static void _vala_tuba_api_instance_v2_api_versions_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec);
static void _vala_tuba_api_instance_v2_api_versions_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec);
static void tuba_api_instance_v2_finalize (GObject * obj);
static GType tuba_api_instance_v2_get_type_once (void);
static void _vala_tuba_api_instance_v2_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec);
static void _vala_tuba_api_instance_v2_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec);

static inline gpointer
tuba_api_instance_v2_get_instance_private (TubaAPIInstanceV2* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIInstanceV2_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

TubaAPIInstanceV2*
tuba_api_instance_v2_from (JsonNode* node,
                           GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPIInstanceV2* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPIInstanceV2* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_TYPE_INSTANCE_V2, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_IS_INSTANCE_V2 (_tmp0_) ? ((TubaAPIInstanceV2*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

TubaAPIInstanceV2*
tuba_api_instance_v2_construct (GType object_type)
{
	TubaAPIInstanceV2 * self = NULL;
	self = (TubaAPIInstanceV2*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIInstanceV2*
tuba_api_instance_v2_new (void)
{
	return tuba_api_instance_v2_construct (TUBA_API_TYPE_INSTANCE_V2);
}

TubaAPIInstanceV2Configuration*
tuba_api_instance_v2_get_configuration (TubaAPIInstanceV2* self)
{
	TubaAPIInstanceV2Configuration* result;
	TubaAPIInstanceV2Configuration* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_configuration;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_v2_set_configuration (TubaAPIInstanceV2* self,
                                        TubaAPIInstanceV2Configuration* value)
{
	TubaAPIInstanceV2Configuration* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_get_configuration (self);
	if (old_value != value) {
		TubaAPIInstanceV2Configuration* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_configuration);
		self->priv->_configuration = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_PROPERTY]);
	}
}

TubaAPIInstanceV2APIVersions*
tuba_api_instance_v2_get_api_versions (TubaAPIInstanceV2* self)
{
	TubaAPIInstanceV2APIVersions* result;
	TubaAPIInstanceV2APIVersions* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_api_versions;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_v2_set_api_versions (TubaAPIInstanceV2* self,
                                       TubaAPIInstanceV2APIVersions* value)
{
	TubaAPIInstanceV2APIVersions* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_get_api_versions (self);
	if (old_value != value) {
		TubaAPIInstanceV2APIVersions* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_api_versions);
		self->priv->_api_versions = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_properties[TUBA_API_INSTANCE_V2_API_VERSIONS_PROPERTY]);
	}
}

static inline gpointer
tuba_api_instance_v2_configuration_get_instance_private (TubaAPIInstanceV2Configuration* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIInstanceV2Configuration_private_offset);
}

TubaAPIInstanceV2Configuration*
tuba_api_instance_v2_configuration_construct (GType object_type)
{
	TubaAPIInstanceV2Configuration * self = NULL;
	self = (TubaAPIInstanceV2Configuration*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIInstanceV2Configuration*
tuba_api_instance_v2_configuration_new (void)
{
	return tuba_api_instance_v2_configuration_construct (TUBA_API_INSTANCE_V2_TYPE_CONFIGURATION);
}

TubaAPIInstanceV2ConfigurationTranslation*
tuba_api_instance_v2_configuration_get_translation (TubaAPIInstanceV2Configuration* self)
{
	TubaAPIInstanceV2ConfigurationTranslation* result;
	TubaAPIInstanceV2ConfigurationTranslation* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_translation;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_v2_configuration_set_translation (TubaAPIInstanceV2Configuration* self,
                                                    TubaAPIInstanceV2ConfigurationTranslation* value)
{
	TubaAPIInstanceV2ConfigurationTranslation* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_get_translation (self);
	if (old_value != value) {
		TubaAPIInstanceV2ConfigurationTranslation* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_translation);
		self->priv->_translation = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_PROPERTY]);
	}
}

TubaAPIInstanceV2ConfigurationMediaAttachments*
tuba_api_instance_v2_configuration_get_media_attachments (TubaAPIInstanceV2Configuration* self)
{
	TubaAPIInstanceV2ConfigurationMediaAttachments* result;
	TubaAPIInstanceV2ConfigurationMediaAttachments* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_media_attachments;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_v2_configuration_set_media_attachments (TubaAPIInstanceV2Configuration* self,
                                                          TubaAPIInstanceV2ConfigurationMediaAttachments* value)
{
	TubaAPIInstanceV2ConfigurationMediaAttachments* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_get_media_attachments (self);
	if (old_value != value) {
		TubaAPIInstanceV2ConfigurationMediaAttachments* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_media_attachments);
		self->priv->_media_attachments = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_PROPERTY]);
	}
}

TubaAPIInstanceV2ConfigurationVapid*
tuba_api_instance_v2_configuration_get_vapid (TubaAPIInstanceV2Configuration* self)
{
	TubaAPIInstanceV2ConfigurationVapid* result;
	TubaAPIInstanceV2ConfigurationVapid* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_vapid;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_v2_configuration_set_vapid (TubaAPIInstanceV2Configuration* self,
                                              TubaAPIInstanceV2ConfigurationVapid* value)
{
	TubaAPIInstanceV2ConfigurationVapid* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_get_vapid (self);
	if (old_value != value) {
		TubaAPIInstanceV2ConfigurationVapid* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_vapid);
		self->priv->_vapid = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PROPERTY]);
	}
}

TubaAPIInstanceV2ConfigurationAccountsCharLimits*
tuba_api_instance_v2_configuration_get_accounts (TubaAPIInstanceV2Configuration* self)
{
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* result;
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_accounts;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_v2_configuration_set_accounts (TubaAPIInstanceV2Configuration* self,
                                                 TubaAPIInstanceV2ConfigurationAccountsCharLimits* value)
{
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_get_accounts (self);
	if (old_value != value) {
		TubaAPIInstanceV2ConfigurationAccountsCharLimits* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_accounts);
		self->priv->_accounts = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_PROPERTY]);
	}
}

static inline gpointer
tuba_api_instance_v2_configuration_translation_get_instance_private (TubaAPIInstanceV2ConfigurationTranslation* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIInstanceV2ConfigurationTranslation_private_offset);
}

TubaAPIInstanceV2ConfigurationTranslation*
tuba_api_instance_v2_configuration_translation_construct (GType object_type)
{
	TubaAPIInstanceV2ConfigurationTranslation * self = NULL;
	self = (TubaAPIInstanceV2ConfigurationTranslation*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIInstanceV2ConfigurationTranslation*
tuba_api_instance_v2_configuration_translation_new (void)
{
	return tuba_api_instance_v2_configuration_translation_construct (TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_TRANSLATION);
}

gboolean
tuba_api_instance_v2_configuration_translation_get_enabled (TubaAPIInstanceV2ConfigurationTranslation* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_enabled;
	return result;
}

void
tuba_api_instance_v2_configuration_translation_set_enabled (TubaAPIInstanceV2ConfigurationTranslation* self,
                                                            gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_translation_get_enabled (self);
	if (old_value != value) {
		self->priv->_enabled = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_translation_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_ENABLED_PROPERTY]);
	}
}

static void
tuba_api_instance_v2_configuration_translation_class_init (TubaAPIInstanceV2ConfigurationTranslationClass * klass,
                                                           gpointer klass_data)
{
	tuba_api_instance_v2_configuration_translation_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIInstanceV2ConfigurationTranslation_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_instance_v2_configuration_translation_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_instance_v2_configuration_translation_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_instance_v2_configuration_translation_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_ENABLED_PROPERTY, tuba_api_instance_v2_configuration_translation_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_ENABLED_PROPERTY] = g_param_spec_boolean ("enabled", "enabled", "enabled", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_instance_v2_configuration_translation_instance_init (TubaAPIInstanceV2ConfigurationTranslation * self,
                                                              gpointer klass)
{
	self->priv = tuba_api_instance_v2_configuration_translation_get_instance_private (self);
	self->priv->_enabled = FALSE;
}

static void
tuba_api_instance_v2_configuration_translation_finalize (GObject * obj)
{
	TubaAPIInstanceV2ConfigurationTranslation * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_TRANSLATION, TubaAPIInstanceV2ConfigurationTranslation);
	G_OBJECT_CLASS (tuba_api_instance_v2_configuration_translation_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_instance_v2_configuration_translation_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIInstanceV2ConfigurationTranslationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_instance_v2_configuration_translation_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIInstanceV2ConfigurationTranslation), 0, (GInstanceInitFunc) tuba_api_instance_v2_configuration_translation_instance_init, NULL };
	GType tuba_api_instance_v2_configuration_translation_type_id;
	tuba_api_instance_v2_configuration_translation_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIInstanceV2ConfigurationTranslation", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIInstanceV2ConfigurationTranslation_private_offset = g_type_add_instance_private (tuba_api_instance_v2_configuration_translation_type_id, sizeof (TubaAPIInstanceV2ConfigurationTranslationPrivate));
	return tuba_api_instance_v2_configuration_translation_type_id;
}

GType
tuba_api_instance_v2_configuration_translation_get_type (void)
{
	static GType tuba_api_instance_v2_configuration_translation_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_instance_v2_configuration_translation_type_id__once)) {
		GType tuba_api_instance_v2_configuration_translation_type_id;
		tuba_api_instance_v2_configuration_translation_type_id = tuba_api_instance_v2_configuration_translation_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_instance_v2_configuration_translation_type_id__once, tuba_api_instance_v2_configuration_translation_type_id);
	}
	return tuba_api_instance_v2_configuration_translation_type_id__once;
}

static void
_vala_tuba_api_instance_v2_configuration_translation_get_property (GObject * object,
                                                                   guint property_id,
                                                                   GValue * value,
                                                                   GParamSpec * pspec)
{
	TubaAPIInstanceV2ConfigurationTranslation * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_TRANSLATION, TubaAPIInstanceV2ConfigurationTranslation);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_ENABLED_PROPERTY:
		g_value_set_boolean (value, tuba_api_instance_v2_configuration_translation_get_enabled (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_instance_v2_configuration_translation_set_property (GObject * object,
                                                                   guint property_id,
                                                                   const GValue * value,
                                                                   GParamSpec * pspec)
{
	TubaAPIInstanceV2ConfigurationTranslation * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_TRANSLATION, TubaAPIInstanceV2ConfigurationTranslation);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_ENABLED_PROPERTY:
		tuba_api_instance_v2_configuration_translation_set_enabled (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
tuba_api_instance_v2_configuration_media_attachments_get_instance_private (TubaAPIInstanceV2ConfigurationMediaAttachments* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIInstanceV2ConfigurationMediaAttachments_private_offset);
}

TubaAPIInstanceV2ConfigurationMediaAttachments*
tuba_api_instance_v2_configuration_media_attachments_construct (GType object_type)
{
	TubaAPIInstanceV2ConfigurationMediaAttachments * self = NULL;
	self = (TubaAPIInstanceV2ConfigurationMediaAttachments*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIInstanceV2ConfigurationMediaAttachments*
tuba_api_instance_v2_configuration_media_attachments_new (void)
{
	return tuba_api_instance_v2_configuration_media_attachments_construct (TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS);
}

gint64
tuba_api_instance_v2_configuration_media_attachments_get_description_limit (TubaAPIInstanceV2ConfigurationMediaAttachments* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_description_limit;
	return result;
}

void
tuba_api_instance_v2_configuration_media_attachments_set_description_limit (TubaAPIInstanceV2ConfigurationMediaAttachments* self,
                                                                            gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_media_attachments_get_description_limit (self);
	if (old_value != value) {
		self->priv->_description_limit = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_media_attachments_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_DESCRIPTION_LIMIT_PROPERTY]);
	}
}

static void
tuba_api_instance_v2_configuration_media_attachments_class_init (TubaAPIInstanceV2ConfigurationMediaAttachmentsClass * klass,
                                                                 gpointer klass_data)
{
	tuba_api_instance_v2_configuration_media_attachments_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIInstanceV2ConfigurationMediaAttachments_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_instance_v2_configuration_media_attachments_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_instance_v2_configuration_media_attachments_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_instance_v2_configuration_media_attachments_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_DESCRIPTION_LIMIT_PROPERTY, tuba_api_instance_v2_configuration_media_attachments_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_DESCRIPTION_LIMIT_PROPERTY] = g_param_spec_int64 ("description-limit", "description-limit", "description-limit", G_MININT64, G_MAXINT64, (gint64) 1500, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_instance_v2_configuration_media_attachments_instance_init (TubaAPIInstanceV2ConfigurationMediaAttachments * self,
                                                                    gpointer klass)
{
	self->priv = tuba_api_instance_v2_configuration_media_attachments_get_instance_private (self);
	self->priv->_description_limit = (gint64) 1500;
}

static void
tuba_api_instance_v2_configuration_media_attachments_finalize (GObject * obj)
{
	TubaAPIInstanceV2ConfigurationMediaAttachments * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIInstanceV2ConfigurationMediaAttachments);
	G_OBJECT_CLASS (tuba_api_instance_v2_configuration_media_attachments_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_instance_v2_configuration_media_attachments_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIInstanceV2ConfigurationMediaAttachmentsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_instance_v2_configuration_media_attachments_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIInstanceV2ConfigurationMediaAttachments), 0, (GInstanceInitFunc) tuba_api_instance_v2_configuration_media_attachments_instance_init, NULL };
	GType tuba_api_instance_v2_configuration_media_attachments_type_id;
	tuba_api_instance_v2_configuration_media_attachments_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIInstanceV2ConfigurationMediaAttachments", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIInstanceV2ConfigurationMediaAttachments_private_offset = g_type_add_instance_private (tuba_api_instance_v2_configuration_media_attachments_type_id, sizeof (TubaAPIInstanceV2ConfigurationMediaAttachmentsPrivate));
	return tuba_api_instance_v2_configuration_media_attachments_type_id;
}

GType
tuba_api_instance_v2_configuration_media_attachments_get_type (void)
{
	static GType tuba_api_instance_v2_configuration_media_attachments_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_instance_v2_configuration_media_attachments_type_id__once)) {
		GType tuba_api_instance_v2_configuration_media_attachments_type_id;
		tuba_api_instance_v2_configuration_media_attachments_type_id = tuba_api_instance_v2_configuration_media_attachments_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_instance_v2_configuration_media_attachments_type_id__once, tuba_api_instance_v2_configuration_media_attachments_type_id);
	}
	return tuba_api_instance_v2_configuration_media_attachments_type_id__once;
}

static void
_vala_tuba_api_instance_v2_configuration_media_attachments_get_property (GObject * object,
                                                                         guint property_id,
                                                                         GValue * value,
                                                                         GParamSpec * pspec)
{
	TubaAPIInstanceV2ConfigurationMediaAttachments * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIInstanceV2ConfigurationMediaAttachments);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_DESCRIPTION_LIMIT_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_v2_configuration_media_attachments_get_description_limit (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_instance_v2_configuration_media_attachments_set_property (GObject * object,
                                                                         guint property_id,
                                                                         const GValue * value,
                                                                         GParamSpec * pspec)
{
	TubaAPIInstanceV2ConfigurationMediaAttachments * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIInstanceV2ConfigurationMediaAttachments);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_DESCRIPTION_LIMIT_PROPERTY:
		tuba_api_instance_v2_configuration_media_attachments_set_description_limit (self, g_value_get_int64 (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
tuba_api_instance_v2_configuration_vapid_get_instance_private (TubaAPIInstanceV2ConfigurationVapid* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIInstanceV2ConfigurationVapid_private_offset);
}

TubaAPIInstanceV2ConfigurationVapid*
tuba_api_instance_v2_configuration_vapid_construct (GType object_type)
{
	TubaAPIInstanceV2ConfigurationVapid * self = NULL;
	self = (TubaAPIInstanceV2ConfigurationVapid*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIInstanceV2ConfigurationVapid*
tuba_api_instance_v2_configuration_vapid_new (void)
{
	return tuba_api_instance_v2_configuration_vapid_construct (TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_VAPID);
}

const gchar*
tuba_api_instance_v2_configuration_vapid_get_public_key (TubaAPIInstanceV2ConfigurationVapid* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_public_key;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_v2_configuration_vapid_set_public_key (TubaAPIInstanceV2ConfigurationVapid* self,
                                                         const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_vapid_get_public_key (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_public_key);
		self->priv->_public_key = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_vapid_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PUBLIC_KEY_PROPERTY]);
	}
}

static void
tuba_api_instance_v2_configuration_vapid_class_init (TubaAPIInstanceV2ConfigurationVapidClass * klass,
                                                     gpointer klass_data)
{
	tuba_api_instance_v2_configuration_vapid_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIInstanceV2ConfigurationVapid_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_instance_v2_configuration_vapid_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_instance_v2_configuration_vapid_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_instance_v2_configuration_vapid_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PUBLIC_KEY_PROPERTY, tuba_api_instance_v2_configuration_vapid_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PUBLIC_KEY_PROPERTY] = g_param_spec_string ("public-key", "public-key", "public-key", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_instance_v2_configuration_vapid_instance_init (TubaAPIInstanceV2ConfigurationVapid * self,
                                                        gpointer klass)
{
	self->priv = tuba_api_instance_v2_configuration_vapid_get_instance_private (self);
}

static void
tuba_api_instance_v2_configuration_vapid_finalize (GObject * obj)
{
	TubaAPIInstanceV2ConfigurationVapid * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_VAPID, TubaAPIInstanceV2ConfigurationVapid);
	_g_free0 (self->priv->_public_key);
	G_OBJECT_CLASS (tuba_api_instance_v2_configuration_vapid_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_instance_v2_configuration_vapid_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIInstanceV2ConfigurationVapidClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_instance_v2_configuration_vapid_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIInstanceV2ConfigurationVapid), 0, (GInstanceInitFunc) tuba_api_instance_v2_configuration_vapid_instance_init, NULL };
	GType tuba_api_instance_v2_configuration_vapid_type_id;
	tuba_api_instance_v2_configuration_vapid_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIInstanceV2ConfigurationVapid", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIInstanceV2ConfigurationVapid_private_offset = g_type_add_instance_private (tuba_api_instance_v2_configuration_vapid_type_id, sizeof (TubaAPIInstanceV2ConfigurationVapidPrivate));
	return tuba_api_instance_v2_configuration_vapid_type_id;
}

GType
tuba_api_instance_v2_configuration_vapid_get_type (void)
{
	static GType tuba_api_instance_v2_configuration_vapid_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_instance_v2_configuration_vapid_type_id__once)) {
		GType tuba_api_instance_v2_configuration_vapid_type_id;
		tuba_api_instance_v2_configuration_vapid_type_id = tuba_api_instance_v2_configuration_vapid_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_instance_v2_configuration_vapid_type_id__once, tuba_api_instance_v2_configuration_vapid_type_id);
	}
	return tuba_api_instance_v2_configuration_vapid_type_id__once;
}

static void
_vala_tuba_api_instance_v2_configuration_vapid_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec)
{
	TubaAPIInstanceV2ConfigurationVapid * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_VAPID, TubaAPIInstanceV2ConfigurationVapid);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PUBLIC_KEY_PROPERTY:
		g_value_set_string (value, tuba_api_instance_v2_configuration_vapid_get_public_key (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_instance_v2_configuration_vapid_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec)
{
	TubaAPIInstanceV2ConfigurationVapid * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_VAPID, TubaAPIInstanceV2ConfigurationVapid);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PUBLIC_KEY_PROPERTY:
		tuba_api_instance_v2_configuration_vapid_set_public_key (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
tuba_api_instance_v2_configuration_accounts_char_limits_get_instance_private (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIInstanceV2ConfigurationAccountsCharLimits_private_offset);
}

TubaAPIInstanceV2ConfigurationAccountsCharLimits*
tuba_api_instance_v2_configuration_accounts_char_limits_construct (GType object_type)
{
	TubaAPIInstanceV2ConfigurationAccountsCharLimits * self = NULL;
	self = (TubaAPIInstanceV2ConfigurationAccountsCharLimits*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIInstanceV2ConfigurationAccountsCharLimits*
tuba_api_instance_v2_configuration_accounts_char_limits_new (void)
{
	return tuba_api_instance_v2_configuration_accounts_char_limits_construct (TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS);
}

gint64
tuba_api_instance_v2_configuration_accounts_char_limits_get_max_display_name_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_max_display_name_length;
	return result;
}

void
tuba_api_instance_v2_configuration_accounts_char_limits_set_max_display_name_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                     gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_accounts_char_limits_get_max_display_name_length (self);
	if (old_value != value) {
		self->priv->_max_display_name_length = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_DISPLAY_NAME_LENGTH_PROPERTY]);
	}
}

gint64
tuba_api_instance_v2_configuration_accounts_char_limits_get_max_note_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_max_note_length;
	return result;
}

void
tuba_api_instance_v2_configuration_accounts_char_limits_set_max_note_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                             gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_accounts_char_limits_get_max_note_length (self);
	if (old_value != value) {
		self->priv->_max_note_length = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_NOTE_LENGTH_PROPERTY]);
	}
}

gint64
tuba_api_instance_v2_configuration_accounts_char_limits_get_max_avatar_description_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_max_avatar_description_length;
	return result;
}

void
tuba_api_instance_v2_configuration_accounts_char_limits_set_max_avatar_description_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                           gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_accounts_char_limits_get_max_avatar_description_length (self);
	if (old_value != value) {
		self->priv->_max_avatar_description_length = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_AVATAR_DESCRIPTION_LENGTH_PROPERTY]);
	}
}

gint64
tuba_api_instance_v2_configuration_accounts_char_limits_get_max_header_description_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_max_header_description_length;
	return result;
}

void
tuba_api_instance_v2_configuration_accounts_char_limits_set_max_header_description_length (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                           gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_accounts_char_limits_get_max_header_description_length (self);
	if (old_value != value) {
		self->priv->_max_header_description_length = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_HEADER_DESCRIPTION_LENGTH_PROPERTY]);
	}
}

gint64
tuba_api_instance_v2_configuration_accounts_char_limits_get_max_profile_fields (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_max_profile_fields;
	return result;
}

void
tuba_api_instance_v2_configuration_accounts_char_limits_set_max_profile_fields (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_accounts_char_limits_get_max_profile_fields (self);
	if (old_value != value) {
		self->priv->_max_profile_fields = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_PROFILE_FIELDS_PROPERTY]);
	}
}

gint64
tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_name_limit (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_profile_field_name_limit;
	return result;
}

void
tuba_api_instance_v2_configuration_accounts_char_limits_set_profile_field_name_limit (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                      gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_name_limit (self);
	if (old_value != value) {
		self->priv->_profile_field_name_limit = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_NAME_LIMIT_PROPERTY]);
	}
}

gint64
tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_value_limit (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_profile_field_value_limit;
	return result;
}

void
tuba_api_instance_v2_configuration_accounts_char_limits_set_profile_field_value_limit (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self,
                                                                                       gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_value_limit (self);
	if (old_value != value) {
		self->priv->_profile_field_value_limit = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_VALUE_LIMIT_PROPERTY]);
	}
}

static void
tuba_api_instance_v2_configuration_accounts_char_limits_class_init (TubaAPIInstanceV2ConfigurationAccountsCharLimitsClass * klass,
                                                                    gpointer klass_data)
{
	tuba_api_instance_v2_configuration_accounts_char_limits_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIInstanceV2ConfigurationAccountsCharLimits_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_instance_v2_configuration_accounts_char_limits_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_instance_v2_configuration_accounts_char_limits_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_instance_v2_configuration_accounts_char_limits_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_DISPLAY_NAME_LENGTH_PROPERTY, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_DISPLAY_NAME_LENGTH_PROPERTY] = g_param_spec_int64 ("max-display-name-length", "max-display-name-length", "max-display-name-length", G_MININT64, G_MAXINT64, (gint64) 40, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_NOTE_LENGTH_PROPERTY, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_NOTE_LENGTH_PROPERTY] = g_param_spec_int64 ("max-note-length", "max-note-length", "max-note-length", G_MININT64, G_MAXINT64, (gint64) 500, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_AVATAR_DESCRIPTION_LENGTH_PROPERTY, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_AVATAR_DESCRIPTION_LENGTH_PROPERTY] = g_param_spec_int64 ("max-avatar-description-length", "max-avatar-description-length", "max-avatar-description-length", G_MININT64, G_MAXINT64, (gint64) 150, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_HEADER_DESCRIPTION_LENGTH_PROPERTY, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_HEADER_DESCRIPTION_LENGTH_PROPERTY] = g_param_spec_int64 ("max-header-description-length", "max-header-description-length", "max-header-description-length", G_MININT64, G_MAXINT64, (gint64) 150, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_PROFILE_FIELDS_PROPERTY, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_PROFILE_FIELDS_PROPERTY] = g_param_spec_int64 ("max-profile-fields", "max-profile-fields", "max-profile-fields", G_MININT64, G_MAXINT64, (gint64) 4, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_NAME_LIMIT_PROPERTY, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_NAME_LIMIT_PROPERTY] = g_param_spec_int64 ("profile-field-name-limit", "profile-field-name-limit", "profile-field-name-limit", G_MININT64, G_MAXINT64, (gint64) 255, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_VALUE_LIMIT_PROPERTY, tuba_api_instance_v2_configuration_accounts_char_limits_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_VALUE_LIMIT_PROPERTY] = g_param_spec_int64 ("profile-field-value-limit", "profile-field-value-limit", "profile-field-value-limit", G_MININT64, G_MAXINT64, (gint64) 255, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_instance_v2_configuration_accounts_char_limits_instance_init (TubaAPIInstanceV2ConfigurationAccountsCharLimits * self,
                                                                       gpointer klass)
{
	self->priv = tuba_api_instance_v2_configuration_accounts_char_limits_get_instance_private (self);
	self->priv->_max_display_name_length = (gint64) 40;
	self->priv->_max_note_length = (gint64) 500;
	self->priv->_max_avatar_description_length = (gint64) 150;
	self->priv->_max_header_description_length = (gint64) 150;
	self->priv->_max_profile_fields = (gint64) 4;
	self->priv->_profile_field_name_limit = (gint64) 255;
	self->priv->_profile_field_value_limit = (gint64) 255;
}

static void
tuba_api_instance_v2_configuration_accounts_char_limits_finalize (GObject * obj)
{
	TubaAPIInstanceV2ConfigurationAccountsCharLimits * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS, TubaAPIInstanceV2ConfigurationAccountsCharLimits);
	G_OBJECT_CLASS (tuba_api_instance_v2_configuration_accounts_char_limits_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_instance_v2_configuration_accounts_char_limits_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIInstanceV2ConfigurationAccountsCharLimitsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_instance_v2_configuration_accounts_char_limits_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIInstanceV2ConfigurationAccountsCharLimits), 0, (GInstanceInitFunc) tuba_api_instance_v2_configuration_accounts_char_limits_instance_init, NULL };
	GType tuba_api_instance_v2_configuration_accounts_char_limits_type_id;
	tuba_api_instance_v2_configuration_accounts_char_limits_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIInstanceV2ConfigurationAccountsCharLimits", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIInstanceV2ConfigurationAccountsCharLimits_private_offset = g_type_add_instance_private (tuba_api_instance_v2_configuration_accounts_char_limits_type_id, sizeof (TubaAPIInstanceV2ConfigurationAccountsCharLimitsPrivate));
	return tuba_api_instance_v2_configuration_accounts_char_limits_type_id;
}

GType
tuba_api_instance_v2_configuration_accounts_char_limits_get_type (void)
{
	static GType tuba_api_instance_v2_configuration_accounts_char_limits_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_instance_v2_configuration_accounts_char_limits_type_id__once)) {
		GType tuba_api_instance_v2_configuration_accounts_char_limits_type_id;
		tuba_api_instance_v2_configuration_accounts_char_limits_type_id = tuba_api_instance_v2_configuration_accounts_char_limits_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_instance_v2_configuration_accounts_char_limits_type_id__once, tuba_api_instance_v2_configuration_accounts_char_limits_type_id);
	}
	return tuba_api_instance_v2_configuration_accounts_char_limits_type_id__once;
}

static void
_vala_tuba_api_instance_v2_configuration_accounts_char_limits_get_property (GObject * object,
                                                                            guint property_id,
                                                                            GValue * value,
                                                                            GParamSpec * pspec)
{
	TubaAPIInstanceV2ConfigurationAccountsCharLimits * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS, TubaAPIInstanceV2ConfigurationAccountsCharLimits);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_DISPLAY_NAME_LENGTH_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_v2_configuration_accounts_char_limits_get_max_display_name_length (self));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_NOTE_LENGTH_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_v2_configuration_accounts_char_limits_get_max_note_length (self));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_AVATAR_DESCRIPTION_LENGTH_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_v2_configuration_accounts_char_limits_get_max_avatar_description_length (self));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_HEADER_DESCRIPTION_LENGTH_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_v2_configuration_accounts_char_limits_get_max_header_description_length (self));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_PROFILE_FIELDS_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_v2_configuration_accounts_char_limits_get_max_profile_fields (self));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_NAME_LIMIT_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_name_limit (self));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_VALUE_LIMIT_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_value_limit (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_instance_v2_configuration_accounts_char_limits_set_property (GObject * object,
                                                                            guint property_id,
                                                                            const GValue * value,
                                                                            GParamSpec * pspec)
{
	TubaAPIInstanceV2ConfigurationAccountsCharLimits * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS, TubaAPIInstanceV2ConfigurationAccountsCharLimits);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_DISPLAY_NAME_LENGTH_PROPERTY:
		tuba_api_instance_v2_configuration_accounts_char_limits_set_max_display_name_length (self, g_value_get_int64 (value));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_NOTE_LENGTH_PROPERTY:
		tuba_api_instance_v2_configuration_accounts_char_limits_set_max_note_length (self, g_value_get_int64 (value));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_AVATAR_DESCRIPTION_LENGTH_PROPERTY:
		tuba_api_instance_v2_configuration_accounts_char_limits_set_max_avatar_description_length (self, g_value_get_int64 (value));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_HEADER_DESCRIPTION_LENGTH_PROPERTY:
		tuba_api_instance_v2_configuration_accounts_char_limits_set_max_header_description_length (self, g_value_get_int64 (value));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_MAX_PROFILE_FIELDS_PROPERTY:
		tuba_api_instance_v2_configuration_accounts_char_limits_set_max_profile_fields (self, g_value_get_int64 (value));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_NAME_LIMIT_PROPERTY:
		tuba_api_instance_v2_configuration_accounts_char_limits_set_profile_field_name_limit (self, g_value_get_int64 (value));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_PROFILE_FIELD_VALUE_LIMIT_PROPERTY:
		tuba_api_instance_v2_configuration_accounts_char_limits_set_profile_field_value_limit (self, g_value_get_int64 (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_instance_v2_configuration_class_init (TubaAPIInstanceV2ConfigurationClass * klass,
                                               gpointer klass_data)
{
	tuba_api_instance_v2_configuration_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIInstanceV2Configuration_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_instance_v2_configuration_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_instance_v2_configuration_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_instance_v2_configuration_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_PROPERTY, tuba_api_instance_v2_configuration_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_PROPERTY] = g_param_spec_object ("translation", "translation", "translation", TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_TRANSLATION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_PROPERTY, tuba_api_instance_v2_configuration_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_PROPERTY] = g_param_spec_object ("media-attachments", "media-attachments", "media-attachments", TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PROPERTY, tuba_api_instance_v2_configuration_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PROPERTY] = g_param_spec_object ("vapid", "vapid", "vapid", TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_VAPID, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_PROPERTY, tuba_api_instance_v2_configuration_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_PROPERTY] = g_param_spec_object ("accounts", "accounts", "accounts", TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_instance_v2_configuration_instance_init (TubaAPIInstanceV2Configuration * self,
                                                  gpointer klass)
{
	self->priv = tuba_api_instance_v2_configuration_get_instance_private (self);
	self->priv->_translation = NULL;
	self->priv->_media_attachments = NULL;
	self->priv->_vapid = NULL;
	self->priv->_accounts = NULL;
}

static void
tuba_api_instance_v2_configuration_finalize (GObject * obj)
{
	TubaAPIInstanceV2Configuration * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_INSTANCE_V2_TYPE_CONFIGURATION, TubaAPIInstanceV2Configuration);
	_g_object_unref0 (self->priv->_translation);
	_g_object_unref0 (self->priv->_media_attachments);
	_g_object_unref0 (self->priv->_vapid);
	_g_object_unref0 (self->priv->_accounts);
	G_OBJECT_CLASS (tuba_api_instance_v2_configuration_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_instance_v2_configuration_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIInstanceV2ConfigurationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_instance_v2_configuration_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIInstanceV2Configuration), 0, (GInstanceInitFunc) tuba_api_instance_v2_configuration_instance_init, NULL };
	GType tuba_api_instance_v2_configuration_type_id;
	tuba_api_instance_v2_configuration_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIInstanceV2Configuration", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIInstanceV2Configuration_private_offset = g_type_add_instance_private (tuba_api_instance_v2_configuration_type_id, sizeof (TubaAPIInstanceV2ConfigurationPrivate));
	return tuba_api_instance_v2_configuration_type_id;
}

GType
tuba_api_instance_v2_configuration_get_type (void)
{
	static GType tuba_api_instance_v2_configuration_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_instance_v2_configuration_type_id__once)) {
		GType tuba_api_instance_v2_configuration_type_id;
		tuba_api_instance_v2_configuration_type_id = tuba_api_instance_v2_configuration_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_instance_v2_configuration_type_id__once, tuba_api_instance_v2_configuration_type_id);
	}
	return tuba_api_instance_v2_configuration_type_id__once;
}

static void
_vala_tuba_api_instance_v2_configuration_get_property (GObject * object,
                                                       guint property_id,
                                                       GValue * value,
                                                       GParamSpec * pspec)
{
	TubaAPIInstanceV2Configuration * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_TYPE_CONFIGURATION, TubaAPIInstanceV2Configuration);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_PROPERTY:
		g_value_set_object (value, tuba_api_instance_v2_configuration_get_translation (self));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_PROPERTY:
		g_value_set_object (value, tuba_api_instance_v2_configuration_get_media_attachments (self));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PROPERTY:
		g_value_set_object (value, tuba_api_instance_v2_configuration_get_vapid (self));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_PROPERTY:
		g_value_set_object (value, tuba_api_instance_v2_configuration_get_accounts (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_instance_v2_configuration_set_property (GObject * object,
                                                       guint property_id,
                                                       const GValue * value,
                                                       GParamSpec * pspec)
{
	TubaAPIInstanceV2Configuration * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_TYPE_CONFIGURATION, TubaAPIInstanceV2Configuration);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_TRANSLATION_PROPERTY:
		tuba_api_instance_v2_configuration_set_translation (self, g_value_get_object (value));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_MEDIA_ATTACHMENTS_PROPERTY:
		tuba_api_instance_v2_configuration_set_media_attachments (self, g_value_get_object (value));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_VAPID_PROPERTY:
		tuba_api_instance_v2_configuration_set_vapid (self, g_value_get_object (value));
		break;
		case TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_PROPERTY:
		tuba_api_instance_v2_configuration_set_accounts (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
tuba_api_instance_v2_api_versions_get_instance_private (TubaAPIInstanceV2APIVersions* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIInstanceV2APIVersions_private_offset);
}

gboolean
tuba_api_instance_v2_api_versions_tuba_same (TubaAPIInstanceV2APIVersions* self,
                                             TubaAPIInstanceV2APIVersions* new_val)
{
	gboolean _tmp0_ = FALSE;
	gint8 _tmp1_;
	gint8 _tmp2_;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (new_val != NULL, FALSE);
	_tmp1_ = new_val->priv->_mastodon;
	_tmp2_ = self->priv->_mastodon;
	if (_tmp1_ == _tmp2_) {
		gint8 _tmp3_;
		gint8 _tmp4_;
		_tmp3_ = new_val->priv->_chuckya;
		_tmp4_ = self->priv->_chuckya;
		_tmp0_ = _tmp3_ == _tmp4_;
	} else {
		_tmp0_ = FALSE;
	}
	result = _tmp0_;
	return result;
}

TubaAPIInstanceV2APIVersions*
tuba_api_instance_v2_api_versions_construct (GType object_type)
{
	TubaAPIInstanceV2APIVersions * self = NULL;
	self = (TubaAPIInstanceV2APIVersions*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIInstanceV2APIVersions*
tuba_api_instance_v2_api_versions_new (void)
{
	return tuba_api_instance_v2_api_versions_construct (TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS);
}

gint8
tuba_api_instance_v2_api_versions_get_mastodon (TubaAPIInstanceV2APIVersions* self)
{
	gint8 result;
	g_return_val_if_fail (self != NULL, -1);
	result = self->priv->_mastodon;
	return result;
}

void
tuba_api_instance_v2_api_versions_set_mastodon (TubaAPIInstanceV2APIVersions* self,
                                                gint8 value)
{
	gint8 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_api_versions_get_mastodon (self);
	if (old_value != value) {
		self->priv->_mastodon = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_api_versions_properties[TUBA_API_INSTANCE_V2_API_VERSIONS_MASTODON_PROPERTY]);
	}
}

gint8
tuba_api_instance_v2_api_versions_get_chuckya (TubaAPIInstanceV2APIVersions* self)
{
	gint8 result;
	g_return_val_if_fail (self != NULL, -1);
	result = self->priv->_chuckya;
	return result;
}

void
tuba_api_instance_v2_api_versions_set_chuckya (TubaAPIInstanceV2APIVersions* self,
                                               gint8 value)
{
	gint8 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_v2_api_versions_get_chuckya (self);
	if (old_value != value) {
		self->priv->_chuckya = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_v2_api_versions_properties[TUBA_API_INSTANCE_V2_API_VERSIONS_CHUCKYA_PROPERTY]);
	}
}

static void
tuba_api_instance_v2_api_versions_class_init (TubaAPIInstanceV2APIVersionsClass * klass,
                                              gpointer klass_data)
{
	tuba_api_instance_v2_api_versions_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIInstanceV2APIVersions_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_instance_v2_api_versions_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_instance_v2_api_versions_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_instance_v2_api_versions_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_API_VERSIONS_MASTODON_PROPERTY, tuba_api_instance_v2_api_versions_properties[TUBA_API_INSTANCE_V2_API_VERSIONS_MASTODON_PROPERTY] = g_param_spec_char ("mastodon", "mastodon", "mastodon", G_MININT8, G_MAXINT8, (gint8) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_API_VERSIONS_CHUCKYA_PROPERTY, tuba_api_instance_v2_api_versions_properties[TUBA_API_INSTANCE_V2_API_VERSIONS_CHUCKYA_PROPERTY] = g_param_spec_char ("chuckya", "chuckya", "chuckya", G_MININT8, G_MAXINT8, (gint8) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_instance_v2_api_versions_instance_init (TubaAPIInstanceV2APIVersions * self,
                                                 gpointer klass)
{
	self->priv = tuba_api_instance_v2_api_versions_get_instance_private (self);
	self->priv->_mastodon = (gint8) 0;
	self->priv->_chuckya = (gint8) 0;
}

static void
tuba_api_instance_v2_api_versions_finalize (GObject * obj)
{
	TubaAPIInstanceV2APIVersions * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersions);
	G_OBJECT_CLASS (tuba_api_instance_v2_api_versions_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_instance_v2_api_versions_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIInstanceV2APIVersionsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_instance_v2_api_versions_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIInstanceV2APIVersions), 0, (GInstanceInitFunc) tuba_api_instance_v2_api_versions_instance_init, NULL };
	GType tuba_api_instance_v2_api_versions_type_id;
	tuba_api_instance_v2_api_versions_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIInstanceV2APIVersions", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIInstanceV2APIVersions_private_offset = g_type_add_instance_private (tuba_api_instance_v2_api_versions_type_id, sizeof (TubaAPIInstanceV2APIVersionsPrivate));
	return tuba_api_instance_v2_api_versions_type_id;
}

GType
tuba_api_instance_v2_api_versions_get_type (void)
{
	static GType tuba_api_instance_v2_api_versions_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_instance_v2_api_versions_type_id__once)) {
		GType tuba_api_instance_v2_api_versions_type_id;
		tuba_api_instance_v2_api_versions_type_id = tuba_api_instance_v2_api_versions_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_instance_v2_api_versions_type_id__once, tuba_api_instance_v2_api_versions_type_id);
	}
	return tuba_api_instance_v2_api_versions_type_id__once;
}

static void
_vala_tuba_api_instance_v2_api_versions_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec)
{
	TubaAPIInstanceV2APIVersions * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersions);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_API_VERSIONS_MASTODON_PROPERTY:
		g_value_set_char (value, tuba_api_instance_v2_api_versions_get_mastodon (self));
		break;
		case TUBA_API_INSTANCE_V2_API_VERSIONS_CHUCKYA_PROPERTY:
		g_value_set_char (value, tuba_api_instance_v2_api_versions_get_chuckya (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_instance_v2_api_versions_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec)
{
	TubaAPIInstanceV2APIVersions * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersions);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_API_VERSIONS_MASTODON_PROPERTY:
		tuba_api_instance_v2_api_versions_set_mastodon (self, g_value_get_char (value));
		break;
		case TUBA_API_INSTANCE_V2_API_VERSIONS_CHUCKYA_PROPERTY:
		tuba_api_instance_v2_api_versions_set_chuckya (self, g_value_get_char (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_instance_v2_class_init (TubaAPIInstanceV2Class * klass,
                                 gpointer klass_data)
{
	tuba_api_instance_v2_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIInstanceV2_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_instance_v2_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_instance_v2_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_instance_v2_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_CONFIGURATION_PROPERTY, tuba_api_instance_v2_properties[TUBA_API_INSTANCE_V2_CONFIGURATION_PROPERTY] = g_param_spec_object ("configuration", "configuration", "configuration", TUBA_API_INSTANCE_V2_TYPE_CONFIGURATION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_V2_API_VERSIONS_PROPERTY, tuba_api_instance_v2_properties[TUBA_API_INSTANCE_V2_API_VERSIONS_PROPERTY] = g_param_spec_object ("api-versions", "api-versions", "api-versions", TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_instance_v2_instance_init (TubaAPIInstanceV2 * self,
                                    gpointer klass)
{
	self->priv = tuba_api_instance_v2_get_instance_private (self);
	self->priv->_configuration = NULL;
	self->priv->_api_versions = NULL;
}

static void
tuba_api_instance_v2_finalize (GObject * obj)
{
	TubaAPIInstanceV2 * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_INSTANCE_V2, TubaAPIInstanceV2);
	_g_object_unref0 (self->priv->_configuration);
	_g_object_unref0 (self->priv->_api_versions);
	G_OBJECT_CLASS (tuba_api_instance_v2_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_instance_v2_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIInstanceV2Class), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_instance_v2_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIInstanceV2), 0, (GInstanceInitFunc) tuba_api_instance_v2_instance_init, NULL };
	GType tuba_api_instance_v2_type_id;
	tuba_api_instance_v2_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIInstanceV2", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIInstanceV2_private_offset = g_type_add_instance_private (tuba_api_instance_v2_type_id, sizeof (TubaAPIInstanceV2Private));
	return tuba_api_instance_v2_type_id;
}

GType
tuba_api_instance_v2_get_type (void)
{
	static GType tuba_api_instance_v2_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_instance_v2_type_id__once)) {
		GType tuba_api_instance_v2_type_id;
		tuba_api_instance_v2_type_id = tuba_api_instance_v2_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_instance_v2_type_id__once, tuba_api_instance_v2_type_id);
	}
	return tuba_api_instance_v2_type_id__once;
}

static void
_vala_tuba_api_instance_v2_get_property (GObject * object,
                                         guint property_id,
                                         GValue * value,
                                         GParamSpec * pspec)
{
	TubaAPIInstanceV2 * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_INSTANCE_V2, TubaAPIInstanceV2);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_PROPERTY:
		g_value_set_object (value, tuba_api_instance_v2_get_configuration (self));
		break;
		case TUBA_API_INSTANCE_V2_API_VERSIONS_PROPERTY:
		g_value_set_object (value, tuba_api_instance_v2_get_api_versions (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_instance_v2_set_property (GObject * object,
                                         guint property_id,
                                         const GValue * value,
                                         GParamSpec * pspec)
{
	TubaAPIInstanceV2 * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_INSTANCE_V2, TubaAPIInstanceV2);
	switch (property_id) {
		case TUBA_API_INSTANCE_V2_CONFIGURATION_PROPERTY:
		tuba_api_instance_v2_set_configuration (self, g_value_get_object (value));
		break;
		case TUBA_API_INSTANCE_V2_API_VERSIONS_PROPERTY:
		tuba_api_instance_v2_set_api_versions (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

